@@ -1,7 +1,7 @@
 
 
 from herre.access.object import GraphQLObject
-from typing import List, Optional
+from typing import List, Optional, Union
 
 
 class Widget(GraphQLObject):
@@ -26,6 +26,8 @@ class QueryWidget(Widget):
 class SearchWidget(Widget):
     query: Optional[str]
 
+class IntWidget(Widget):
+    pass
 
 class SliderWidget(Widget):
     """ A Slider widget enables
@@ -39,4 +41,7 @@ class SliderWidget(Widget):
         min(int): The Minimum Value for this Slider
     """
     min: Optional[int]
-    max: Optional[int]
\ No newline at end of file
+    max: Optional[int]
+
+
+AllWidgets = Union[SearchWidget, IntWidget, SliderWidget, QueryWidget, ValueWidget]
\ No newline at end of file
