@@ -1,5 +1,5 @@
 from arkitekt.schema.negotiation import Transcript
-from herre.config.model import BaseConfig
+from herre.config.herre import BaseConfig
 from herre.wards.graphql import ParsedQuery, GraphQLWard
 from herre.auth import HerreClient
 
